@@ -11,7 +11,8 @@ API_URL_MAPPING = {
     'session-command': '/api/terminal/v1/command/',
     'user-auth': '/api/users/v1/auth/',
     'user-assets': '/api/perms/v1/user/%s/assets/',
-    'user-asset-groups': '/api/perms/v1/user/%s/asset-groups-assets/',
+    'user-asset-groups': '/api/perms/v1/user/%s/nodes-assets/',
+    'user-nodes-assets': '/api/perms/v1/user/%s/nodes-assets/',
     'my-profile': '/api/users/v1/profile/',
     'system-user-auth-info': '/api/assets/v1/system-user/%s/auth-info/',
     'validate-user-asset-permission': '/api/perms/v1/asset-permission/user/validate/',
